/* Copyright(C) (2012) (ID - IMAG) <Jean-Marc.Vincent@imag.fr> */

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */



/*! \file generateur.c
 * \brief  experimentation tri par tas
 * \author Jean-Marc.Vincent@imag.fr 
 *
 * \version 1.0
 * \date 2012
 */

/*
 *------------------------------------------------------------------
 * Fichier      : generateur.h
 * Langage      : C 
 * Auteur       : Jean-Marc Vincent
 * Creation     : 23/01/2012
 *--------------------------------------------------------------------
 * Description  :
 *          prototype de la generation de permutations 
 *          aleatoires uniformes dans un tableau
 *--------------------------------------------------------------------
 */

/*
   init_generateur
   description : initialise le generateur
   parametres : aucun
   valeur de retour : germe du generateur
   effets de bord : fixe le germe du generateur
*/
int init_generateur();

/*
   u01
   description : genere un tirage pseudo-aleatoire selon la loi uniforme
                 sur [0,1[
   parametres : aucun
   valeur de retour : reel de [0,1[
   effets de bord : itere le generateur
*/ 
double u01();
 
/*
   init_tableau
   description : initialise les cases d'un tableau avec leur indice
   parametres : tableau, taille du tableau
   valeur de retour : aucune
   effets de bord : modifie le tableau
*/ 
void init_tableau(int *Tableau,int n);

/*
   genere_tableau_beta
   description : initialise les cases d'un tableau avec une permutation 
   aleatoire un peu beta
   parametres : tableau, taille du tableau
   valeur de retour : aucune
   effets de bord : modifie le tableau
*/ 
void genere_tableau_beta(int *Tableau,int n);

/*
   genere_tableau
   description : initialise les cases d'un tableau avec une permutation 
   aleatoire uniforme
   parametres : tableau, taille du tableau
   valeur de retour : aucune
   effets de bord : modifie le tableau
*/ 
void genere_tableau(int *Tableau,int n);

/*
   imprime_tableau
   description : initialise les cases d'un tableau avec une permutation 
   aleatoire uniforme
   parametres : tableau, taille du tableau
   valeur de retour : aucune
   effets de bord : modifie le tableau
*/ 
void imprime_tableau(int *Tableau,int n);

