/* Copyright(C) (2012) (ID - IMAG) <Jean-Marc.Vincent@imag.fr> */

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */



/*! \file main.c
 * \brief  experimentation tri par tas
 * \author Jean-Marc.Vincent@imag.fr 
 *
 * \version 1.0
 * \date 2012
 */

/*
 *------------------------------------------------------------------
 * Fichier      : main.c
 * Langage      : C 
 * Auteur       : Jean-Marc Vincent
 * Creation     : 23/01/2012
 *--------------------------------------------------------------------
 * Description  :
 *          Programme principal contenant le main permettant de lancer
 *   l'evaluation probabiliste de l'algorithme de tri par tas
 *--------------------------------------------------------------------
 */


#include "tri-tas.h"
#include "generateur.h"
#include "statistique.h"

#include <stdio.h>
#include <stdlib.h>

int main(int argc, char **argv)
{
  int dimension, taille_echantillon,taille_histogramme;
  int i;
  int *Tableau;


  int *echantillon;
  double *indices_stat;
  double *hist;
  
  if (argc<3) 
    {
		printf("Arguments:\n   dimension_tableau\n   taille_echantillon\n   nombre_pas_histogramme\n");
		exit(0);
    }
  else
    {
      if (sscanf(argv[1],"%d",&dimension)!=1) exit(1);
      printf("# Dimension du tableau %d \n",dimension);
      if (sscanf(argv[2],"%d",&taille_echantillon)!=1) exit(2);
      printf("# Taille de l'echantillon %d \n",taille_echantillon);
      if (sscanf(argv[3],"%d",&taille_histogramme)!=1) exit(3);
      printf("# Taille de l'histogramme %d \n",taille_histogramme);
    }
	
  Tableau =  malloc(sizeof(int)*dimension);
  
  echantillon =  malloc(sizeof(int)*taille_echantillon);
  indices_stat = malloc(sizeof(double)*7);
  hist = malloc(sizeof(double)*taille_histogramme);

  init_generateur();
  /*
  for(i=0; i< taille_echantillon; i++)
	{
	  int cout;
	 	genere_tableau(Tableau,dimension);
		imprime_tableau(Tableau,dimension);
		cout=tri_tas(Tableau,dimension);
		imprime_tableau(Tableau,dimension);
		printf(" %d \n",cout);
	}
    */
    for(i=0; i< taille_echantillon; i++)
	{
	 	genere_tableau(Tableau,dimension);
        echantillon[i]=tri_tas(Tableau,dimension);
    }

  statistique(indices_stat,echantillon,taille_echantillon);
    
  histogramme(hist,taille_histogramme,indices_stat,echantillon,taille_echantillon);
  imprime_statistique(indices_stat);
  imprime_histogramme(hist,indices_stat,taille_histogramme);


  free(Tableau);
  free(echantillon);
  free(indices_stat);
  free(hist);

  return 0;
}

