/* Copyright(C) (2012) (ID - IMAG) <Jean-Marc.Vincent@imag.fr> */

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */



/*! \file tri-tas.c
 * \brief  experimentation tri par tas
 * \author Jean-Marc.Vincent@imag.fr 
 *
 * \version 1.0
 * \date 2012
 */

/*
 *------------------------------------------------------------------
 * Fichier      : tri-tas.c
 * Langage      : C 
 * Auteur       : Jean-Marc Vincent
 * Creation     : 23/01/2012
 *--------------------------------------------------------------------
 * Description  :
 *          Programme principal contenant l'algorithme de tri par tas
 *--------------------------------------------------------------------
 */

#include "tri-tas.h"
#include <stdlib.h>


/*
 tri-tas
 description : tri en place par tas le tableau T de taille n
 parametres : tableau, taille du tableau
 valeur de retour : nombre d'echanges effectues
 effets de bord : modifie le tableau
 */ 

void echange(int *T, int i,int j)
{
	int e;
	e=T[i];
	T[i]=T[j];
	T[j]=e;
}


inline int plus_grand_fils(int *T, int i, int j){
    /* T est un tas de 0 a i */
    if (2*j+1 > i) {
        return -1;
    } else {
        if (2*j+2>i) {
            return 2*j+1;
        } else {
            if (T[2*j+1] > T[2*j+2]) {
                return 2*j+1;
            } else {
                return 2*j+2;
            }
        }
    }
}

int tri_tas(int* T, int n)
{
    int i,j,k;
    int r=0;
    for (i=1; i<n; i++){
        /* T est un tas de 0 a i-1 */
        j=i;
        while ((j != 0) && (T[(j-1)/2] < T[j])) 
        {
            echange(T,(j-1)/2,j);
            j=(j-1)/2;
            r++;
        }
        /* T est un tas de 0 a i */
    }
    for (i=n-1; i>0; i--) 
    {
        /* T est un tas de 0 a i */
        echange(T,i,0);
        r++;
        j=0;
        k=plus_grand_fils(T,i-1,j);
        while ((k != -1) && (T[k] > T[j])) {
            echange(T,j,k);
            r++;
            j=k;
            k=plus_grand_fils(T,i-1,j);
        }
    } 
    return r;
}

